diff --git a/ChangeLog b/ChangeLog
index c0dc7cad4385b90f0027fc09328d7a1cab397b11..206c5ef95ead996b4e983b67a3c5aa6f28c0e280 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,15 @@
+2006-02-02	Benedikt Meurer <benny@xfce.org>
+
+	* thunar/thunar-icon-renderer.c(thunar_icon_renderer_render): Make it
+	  easier to distinguish hidden and backup files from regular files.
+	* docs/README.thunarrc, thunar/thunar-preferences.c: Rename the
+	  DefaultShowHidden preference to LastShowHidden.
+	* thunar/thunar-preferences-dialog.c, thunar/thunar-window.c: Drop the
+	  "Show hidden files" option from the preferences dialog. Instead Thunar
+	  now preserves the users last selection. This way, the "Show hidden
+	  files" behaviour is now consistent with the rest of the file manager.
+	  Bug #1417.
+
 2006-02-02	Benedikt Meurer <benny@xfce.org>
 
 	* thunar/thunar-shortcuts-model.{c,h}: Drop obsolete method
diff --git a/docs/README.thunarrc b/docs/README.thunarrc
index 3983a8701a4da0b8a53de898cc171edd9234dc17..322ba04f4b709b3c5040145009a9f2c503c69f6b 100644
--- a/docs/README.thunarrc
+++ b/docs/README.thunarrc
@@ -8,11 +8,6 @@ The Thunar Configuration File (thunarrc)
 
   The following list gives a brief overview of the preferences known to Thunar:
 
-   * DefaultShowHidden (FALSE/TRUE)
-
-     Determines whether hidden files should be shown by default in newly
-     opened Thunar windows.
-
    * DefaultView (ThunarDetailsView/ThunarIconView/void)
 
      The name of the widget class, which should be used for the view pane
@@ -44,6 +39,11 @@ The Thunar Configuration File (thunarrc)
      The name of the widget class which should be used for the location bar
      in Thunar windows or "void" to hide the location bar completely.
 
+   * LastShowHidden (FALSE/TRUE)
+
+     Determines whether hidden files should be shown by default in newly
+     opened Thunar windows.
+
    * LastSidePane (ThunarShortcutsPane/void)
 
      The name of the widget class which should be used for the side pane
diff --git a/thunar/thunar-preferences-dialog.c b/thunar/thunar-preferences-dialog.c
index c9331119d24c4edccae5ae61d111321d8cd5cb00..e73b2278d56577e6b4f985f05b49af5e47f40669 100644
--- a/thunar/thunar-preferences-dialog.c
+++ b/thunar/thunar-preferences-dialog.c
@@ -215,7 +215,7 @@ thunar_preferences_dialog_init (ThunarPreferencesDialog *dialog)
   gtk_frame_set_label_widget (GTK_FRAME (frame), label);
   gtk_widget_show (label);
 
-  table = gtk_table_new (4, 2, FALSE);
+  table = gtk_table_new (3, 2, FALSE);
   gtk_table_set_row_spacings (GTK_TABLE (table), 6);
   gtk_table_set_col_spacings (GTK_TABLE (table), 12);
   gtk_container_set_border_width (GTK_CONTAINER (table), 12);
@@ -252,19 +252,11 @@ thunar_preferences_dialog_init (ThunarPreferencesDialog *dialog)
   gtk_table_attach (GTK_TABLE (table), button, 0, 2, 1, 2, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
   gtk_widget_show (button);
 
-  button = gtk_check_button_new_with_mnemonic (_("Show hidden and _backup files"));
-  exo_mutual_binding_new (G_OBJECT (dialog->preferences), "default-show-hidden", G_OBJECT (button), "active");
-  gtk_tooltips_set_tip (dialog->tooltips, button, _("Select this option to show hidden and backup files in new windows. "
-                                                    "The first character in a hidden filename is a period (.). The last "
-                                                    "character in a backup filename is a tilde (~)."), NULL);
-  gtk_table_attach (GTK_TABLE (table), button, 0, 2, 2, 3, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
-  gtk_widget_show (button);
-
   button = gtk_check_button_new_with_mnemonic (_("_Show thumbnails"));
   exo_mutual_binding_new (G_OBJECT (dialog->preferences), "misc-show-thumbnails", G_OBJECT (button), "active");
   gtk_tooltips_set_tip (dialog->tooltips, button, _("Select this option to display previewable files within a "
                                                     "folder as automatically generated thumbnail icons."), NULL);
-  gtk_table_attach (GTK_TABLE (table), button, 0, 2, 3, 4, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+  gtk_table_attach (GTK_TABLE (table), button, 0, 2, 2, 3, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
   gtk_widget_show (button);
 
   frame = g_object_new (GTK_TYPE_FRAME, "border-width", 0, "shadow-type", GTK_SHADOW_NONE, NULL);
diff --git a/thunar/thunar-preferences.c b/thunar/thunar-preferences.c
index f15a18b52a8d3392000327637f12310b9b552ede..f4a55df6ef042eb3303d9b85e654c233d915c3e0 100644
--- a/thunar/thunar-preferences.c
+++ b/thunar/thunar-preferences.c
@@ -49,11 +49,11 @@
 enum
 {
   PROP_0,
-  PROP_DEFAULT_SHOW_HIDDEN,
   PROP_DEFAULT_VIEW,
   PROP_LAST_DETAILS_VIEW_ZOOM_LEVEL,
   PROP_LAST_ICON_VIEW_ZOOM_LEVEL,
   PROP_LAST_LOCATION_BAR,
+  PROP_LAST_SHOW_HIDDEN,
   PROP_LAST_SIDE_PANE,
   PROP_LAST_STATUSBAR_VISIBLE,
   PROP_LAST_VIEW,
@@ -171,19 +171,6 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
   /* register additional transformation functions */
   thunar_g_initialize_transformations ();
 
-  /**
-   * ThunarPreferences:default-show-hidden:
-   *
-   * Whether to show hidden files by default in new windows.
-   **/
-  g_object_class_install_property (gobject_class,
-                                   PROP_DEFAULT_SHOW_HIDDEN,
-                                   g_param_spec_boolean ("default-show-hidden",
-                                                         "default-show-hidden",
-                                                         "default-show-hidden",
-                                                         FALSE,
-                                                         EXO_PARAM_READWRITE));
-
   /**
    * ThunarPreferences:default-view:
    *
@@ -242,6 +229,19 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                                                         "ThunarLocationButtons",
                                                         EXO_PARAM_READWRITE));
 
+  /**
+   * ThunarPreferences:last-show-hidden:
+   *
+   * Whether to show hidden files by default in new windows.
+   **/
+  g_object_class_install_property (gobject_class,
+                                   PROP_LAST_SHOW_HIDDEN,
+                                   g_param_spec_boolean ("last-show-hidden",
+                                                         "last-show-hidden",
+                                                         "last-show-hidden",
+                                                         FALSE,
+                                                         EXO_PARAM_READWRITE));
+
   /**
    * ThunarPreferences:last-side-pane:
    *
diff --git a/thunar/thunar-icon-renderer.c b/thunar/thunar-icon-renderer.c
index ca49764fe31f27e3e4f75911b0f4088d1ef45c4d..6eb4c2b7cb459845a4ac11512b6ef85fa0ae9aa8 100644
--- a/thunar/thunar-icon-renderer.c
+++ b/thunar/thunar-icon-renderer.c
@@ -411,14 +411,22 @@ thunar_icon_renderer_render (GtkCellRenderer     *renderer,
   /* check whether the icon is affected by the expose event */
   if (gdk_rectangle_intersect (expose_area, &icon_area, &draw_area))
     {
       /* use a translucent icon to represent cutted files to the user */
       clipboard = thunar_clipboard_manager_get_for_display (gtk_widget_get_display (widget));
       if (thunar_clipboard_manager_has_cutted_file (clipboard, icon_renderer->file))
         {
+          /* 50% translucent for cutted files */
           temp = thunar_gdk_pixbuf_lucent (icon, 50);
           g_object_unref (G_OBJECT (icon));
           icon = temp;
         }
+      else if (thunar_file_is_hidden (icon_renderer->file))
+        {
+          /* 75% translucent for hidden files */
+          temp = thunar_gdk_pixbuf_lucent (icon, 75);
+          g_object_unref (G_OBJECT (icon));
+          icon = temp;
+        }
       g_object_unref (G_OBJECT (clipboard));
 
       /* colorize the icon if we should follow the selection state */
@@ -411,14 +411,22 @@ thunar_icon_renderer_render (GtkCellRenderer     *renderer,
   if (gdk_rectangle_intersect (expose_area, &icon_area, &draw_area))
     {
-      /* use a translucent icon to represent cutted files to the user */
+      /* use a translucent icon to represent cutted and hidden files to the user */
       clipboard = thunar_clipboard_manager_get_for_display (gtk_widget_get_display (widget));
       if (thunar_clipboard_manager_has_cutted_file (clipboard, icon_renderer->file))
diff --git a/thunar/thunar-window.c b/thunar/thunar-window.c
index 51b4b82ae385d2429501140d1824f9556c2a8153..9167669ef3fce31b79fcb97251cf982dbcf1e481 100644
--- a/thunar/thunar-window.c
+++ b/thunar/thunar-window.c
@@ -456,11 +456,14 @@ thunar_window_init (ThunarWindow *window)
   gtk_action_group_add_actions (window->action_group, action_entries, G_N_ELEMENTS (action_entries), GTK_WIDGET (window));
   gtk_action_group_add_toggle_actions (window->action_group, toggle_action_entries, G_N_ELEMENTS (toggle_action_entries), GTK_WIDGET (window));
 
   /* initialize the "show-hidden" action using the default value from the preferences */
   action = gtk_action_group_get_action (window->action_group, "show-hidden");
-  g_object_get (G_OBJECT (window->preferences), "default-show-hidden", &show_hidden, NULL);
+  g_object_get (G_OBJECT (window->preferences), "last-show-hidden", &show_hidden, NULL);
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), show_hidden);
 
+  /* synchronize the "show-hidden" state with the "last-show-hidden" preference */
+  exo_binding_new (G_OBJECT (window), "show-hidden", G_OBJECT (window->preferences), "last-show-hidden");
+
   /* setup the history support */
   window->history = g_object_new (THUNAR_TYPE_HISTORY, "action-group", window->action_group, NULL);
   g_signal_connect_swapped (G_OBJECT (window->history), "change-directory", G_CALLBACK (thunar_window_set_current_directory), window);
@@ -456,11 +456,14 @@ thunar_window_init (ThunarWindow *window)
   gtk_action_group_add_toggle_actions (window->action_group, toggle_action_entries, G_N_ELEMENTS (toggle_action_entries), GTK_WIDGET (window));
 
-  /* initialize the "show-hidden" action using the default value from the preferences */
+  /* initialize the "show-hidden" action using the last value from the preferences */
   action = gtk_action_group_get_action (window->action_group, "show-hidden");